@@ -43,7 +43,7 @@ class Folders(object):
         * config_file
         * mute
     """
-    URBANOPT_VERSION = (0, 12, 0)
+    URBANOPT_VERSION = (0, 14, 0)
     COMPATIBILITY_URL = 'https://github.com/ladybug-tools/lbt-grasshopper/wiki/' \
         '1.4-Compatibility-Matrix'
 
@@ -215,16 +215,31 @@ class Folders(object):
             os.path.join(home_folder, '.env_uo.sh')
 
         if self.urbanopt_cli_path:  # try to generate the env file
-            env_setup = os.path.join(self.urbanopt_cli_path, 'setup-env.bat') \
-                if os.name == 'nt' else \
-                os.path.join(self.urbanopt_cli_path, 'setup-env.sh')
+            if os.name == 'nt':
+                env_setup = os.path.join(self.urbanopt_cli_path, 'setup-env.bat')
+                if not os.path.isfile(env_setup):
+                    env_setup = os.path.join(self.urbanopt_cli_path, 'setup-env.ps1')
+            else:
+                env_setup = os.path.join(self.urbanopt_cli_path, 'setup-env.sh')
             if os.path.isfile(env_setup):
                 if os.name == 'nt':  # run the batch file on Windows
-                    os.system(env_setup)
+                    if env_setup.endswith('.bat'):
+                        os.system(env_setup)
+                    else:
+                        cmds = ['powershell.exe', env_setup]
+                        p = subprocess.Popen(cmds)
+                        p.communicate()
                 else:  # run the sell file on Mac or Linux
                     subprocess.check_call(['chmod', 'u+x', env_setup])
                     subprocess.call(env_setup)
             if os.path.isfile(env_file):
+                if os.name == 'nt':  # remove the utf-8 encoding powershell does
+                    with open(env_file, 'r') as inf:
+                        env_data = inf.read().splitlines(True)
+                    if not env_data[0] == '\n' and not env_data[0].startswith('SET'):
+                        env_data = env_data[1:]
+                        with open(env_file, 'w') as otf:
+                            otf.write(''.join(env_data))
                 self._urbanopt_env_path = env_file  # the file was successfully generated
 
     def check_urbanopt_version(self):
