@@ -14,7 +14,7 @@ from dragonfly.projection import meters_to_long_lat_factors, \
 
 from .ghe import GroundHeatExchanger, SoilParameter, FluidParameter, \
     PipeParameter, BoreholeParameter, GHEDesignParameter
-from .connector import ThermalConnector
+from .connector import ThermalConnector, HorizontalPipeParameter
 from .junction import ThermalJunction
 
 
@@ -55,6 +55,9 @@ class GHEThermalLoop(object):
         design_parameters: Optional GHEDesignParameter object to specify the
             design constraints across the loop. If None, default values
             will be used. (Default: None).
+        horizontal_pipe_parameters: Optional HorizontalPipeParameter object to specify
+            the properties of the horizontal pipes contained within ThermalConnectors.
+            If None, default values will be used. (Default: None).
 
     Properties:
         * identifier
@@ -67,15 +70,17 @@ class GHEThermalLoop(object):
         * pipe_parameters
         * borehole_parameters
         * design_parameters
+        * horizontal_pipe_parameters
     """
     __slots__ = (
         '_identifier', '_display_name', '_ground_heat_exchangers', '_connectors',
         '_clockwise_flow', '_soil_parameters', '_fluid_parameters', '_pipe_parameters',
-        '_borehole_parameters', '_design_parameters')
+        '_borehole_parameters', '_design_parameters', '_horizontal_pipe_parameters')
 
     def __init__(self, identifier, ground_heat_exchangers, connectors,
                  clockwise_flow=False, soil_parameters=None, fluid_parameters=None,
-                 pipe_parameters=None, borehole_parameters=None, design_parameters=None):
+                 pipe_parameters=None, borehole_parameters=None, design_parameters=None,
+                 horizontal_pipe_parameters=None):
         """Initialize GHEThermalLoop."""
         self.identifier = identifier
         self._display_name = None
@@ -87,6 +92,7 @@ class GHEThermalLoop(object):
         self.pipe_parameters = pipe_parameters
         self.borehole_parameters = borehole_parameters
         self.design_parameters = design_parameters
+        self.horizontal_pipe_parameters = horizontal_pipe_parameters
 
     @classmethod
     def from_dict(cls, data):
@@ -112,7 +118,10 @@ class GHEThermalLoop(object):
             if 'borehole_parameters' in data else None
         des = GHEDesignParameter.from_dict(data['design_parameters']) \
             if 'design_parameters' in data else None
-        loop = cls(data['identifier'], ghe, conns, clock, soil, fluid, pipe, bore, des)
+        hp = HorizontalPipeParameter.from_dict(data['horizontal_pipe_parameters']) \
+            if 'horizontal_pipe_parameters' in data else None
+        loop = cls(data['identifier'], ghe, conns, clock, soil, fluid,
+                   pipe, bore, des, hp)
         if 'display_name' in data and data['display_name'] is not None:
             loop.display_name = data['display_name']
         return loop
@@ -377,6 +386,20 @@ class GHEThermalLoop(object):
             ' for GroundHeatExchanger. Got {}.'.format(type(value))
         self._design_parameters = value
 
+    @property
+    def horizontal_pipe_parameters(self):
+        """Get or set a HorizontalPipeParameter object for the DES loop."""
+        return self._horizontal_pipe_parameters
+
+    @horizontal_pipe_parameters.setter
+    def horizontal_pipe_parameters(self, value):
+        if value is None:
+            value = HorizontalPipeParameter()
+        assert isinstance(value, HorizontalPipeParameter), \
+            'Expected HorizontalPipeParameter object' \
+            ' for GroundHeatExchanger. Got {}.'.format(type(value))
+        self._horizontal_pipe_parameters = value
+
     def junctions(self, tolerance=0.01):
         """Get a list of ThermalJunction objects for the unique thermal loop junctions.
 
@@ -422,7 +445,7 @@ class GHEThermalLoop(object):
         footprint_2d, bldg_ids = GHEThermalLoop._building_footprints(
             buildings, tolerance)
         for ghe in self.ground_heat_exchangers:
-            footprint_2d.append(ghe.geometry)
+            footprint_2d.append(ghe.boundary_2d)
             bldg_ids.append(ghe.identifier)
 
         # determine which ThermalConnectors are linked to the buildings
@@ -469,6 +492,7 @@ class GHEThermalLoop(object):
         loop_poly = loop_geo.to_polygon(tolerance)
         if loop_poly.is_clockwise is not self.clockwise_flow:
             loop_poly = loop_poly.reverse()
+
         return loop_poly
 
     def ordered_connectors(self, buildings, tolerance=0.01):
@@ -597,6 +621,7 @@ class GHEThermalLoop(object):
         base['pipe_parameters'] = self.pipe_parameters.to_dict()
         base['borehole_parameters'] = self.borehole_parameters.to_dict()
         base['design_parameters'] = self.design_parameters.to_dict()
+        base['horizontal_pipe_parameters'] = self.horizontal_pipe_parameters.to_dict()
         if self._display_name is not None:
             base['display_name'] = self.display_name
         return base
@@ -635,14 +660,15 @@ class GHEThermalLoop(object):
         # get the footprints of the Buildings in 2D space
         footprint_2d, bldg_ids = GHEThermalLoop._building_footprints(
             buildings, tolerance)
-        all_feat = footprint_2d + [ghe.geometry for ghe in self.ground_heat_exchangers]
+        all_feat = \
+            footprint_2d + [ghe.boundary_2d for ghe in self.ground_heat_exchangers]
         feat_ids = bldg_ids + [ghe.identifier for ghe in self.ground_heat_exchangers]
 
         # order the connectors correctly on the loop and translate them to features
         ordered_conns = self.ordered_connectors(buildings, tolerance)
         junctions, connector_jct_ids = self._junctions_from_connectors(
             ordered_conns, tolerance)
-        for conn, jct_ids in zip(self.connectors, connector_jct_ids):
+        for conn, jct_ids in zip(ordered_conns, connector_jct_ids):
             st_feat, end_feat, cp1, cp2 = None, None, conn.geometry.p1, conn.geometry.p2
             for f_poly, f_id in zip(all_feat, feat_ids):
                 if f_poly.is_point_on_edge(cp1, tolerance):
@@ -731,10 +757,32 @@ class GHEThermalLoop(object):
             bldg_array.append(b_dict)
         des_dict['buildings'] = bldg_array
 
-        # add the ground loop parameters
+        # handle autocalculated soil temperatures
+        u_temp = self.soil_parameters.undisturbed_temperature \
+            if self.soil_parameters._undisturbed_temperature is not None \
+            else 'Autocalculate'
+
+        # add the fifth generation system parameters
+        hp_par = self.horizontal_pipe_parameters
         des_param = {
             'fifth_generation': {
-                'ghe_parameters': self.to_ghe_param_dict(tolerance)
+                'ghe_parameters': self.to_ghe_param_dict(tolerance),
+                'horizontal_piping_parameters': {
+                    'number_of_segments': 1,
+                    'buried_depth': hp_par.buried_depth,
+                    'hydraulic_diameter': hp_par.hydraulic_diameter,
+                    'diameter_ratio': hp_par.diameter_ratio,
+                    'pressure_drop_per_meter': hp_par.pressure_drop_per_meter,
+                    'insulation_conductivity': hp_par.insulation_conductivity,
+                    'insulation_thickness': hp_par.insulation_thickness,
+                    'rho_cp': hp_par.heat_capacity,
+                    'roughness': hp_par.roughness
+                },
+                'soil': {
+                    'conductivity': self.soil_parameters.conductivity,
+                    'rho_cp': self.soil_parameters.heat_capacity,
+                    'undisturbed_temp': u_temp
+                }
             }
         }
         des_dict['district_system'] = des_param
@@ -751,7 +799,7 @@ class GHEThermalLoop(object):
         # compute the geometric constraints of the borehole fields
         geo_pars = []
         for ghe in self.ground_heat_exchangers:
-            ghe_geo = ghe.geometry
+            ghe_geo = ghe.boundary_2d
             max_dim = max((ghe_geo.max.x - ghe_geo.min.x, ghe_geo.max.y - ghe_geo.min.y))
             ang_tol = tolerance / max_dim
             if ghe_geo.is_rectangle(ang_tol):
@@ -772,10 +820,7 @@ class GHEThermalLoop(object):
                 'ground_loads': []
             }
             geo_pars.append(geo_par)
-        # handle autocalculated soil temperatures
-        u_temp = self.soil_parameters.undisturbed_temperature \
-            if self.soil_parameters._undisturbed_temperature is not None \
-            else 'Autocalculate'
+
         # return a dictionary with all of the information
         return {
             'fluid': {
@@ -787,11 +832,6 @@ class GHEThermalLoop(object):
                 'conductivity': self.soil_parameters.grout_conductivity,
                 'rho_cp': self.soil_parameters.grout_heat_capacity,
             },
-            'soil': {
-                'conductivity': self.soil_parameters.conductivity,
-                'rho_cp': self.soil_parameters.heat_capacity,
-                'undisturbed_temp': u_temp
-            },
             'pipe': {
                 'inner_diameter': self.pipe_parameters.inner_diameter,
                 'outer_diameter': self.pipe_parameters.outer_diameter,
@@ -812,7 +852,7 @@ class GHEThermalLoop(object):
                 'method': 'rectangle'
             },
             'design': {
-                'method': 'AREAPROPORTIONAL',
+                'method': self.design_parameters.method.upper(),
                 'flow_rate': self.design_parameters.flow_rate,
                 'flow_type': self.design_parameters.flow_type.lower(),
                 'max_eft': self.design_parameters.max_eft,
@@ -890,14 +930,14 @@ class GHEThermalLoop(object):
             bnd_poly = Polygon2D([Point2D(pt.x, pt.y) for pt in face.boundary])
             bnd_poly = bnd_poly.remove_colinear_vertices(tolerance)
             if bnd_poly.is_clockwise:
-                bnd_poly = bnd_poly.reverse()
+                bnd_poly.reverse()
             site_boundaries.append([[pt.x, pt.y] for pt in bnd_poly])
             if face.has_holes:
                 for hole in face.holes:
                     hole_poly = Polygon2D([Point2D(pt.x, pt.y) for pt in hole])
                     hole_poly = hole_poly.remove_colinear_vertices(tolerance)
                     if hole_poly.is_clockwise:
-                        hole_poly = hole_poly.reverse()
+                        hole_poly.reverse()
                     site_holes.append([[pt.x, pt.y] for pt in hole_poly])
 
         # set defaults if any of the inputs are unspecified
@@ -1014,7 +1054,7 @@ class GHEThermalLoop(object):
         # loop through district system objects to determine adjacent junctions
         for jct in junctions:
             for ds_obj in self.ground_heat_exchangers:
-                if ds_obj.geometry.is_point_on_edge(jct.geometry, tolerance):
+                if ds_obj.boundary_2d.is_point_on_edge(jct.geometry, tolerance):
                     jct.system_identifier = ds_obj.identifier
                     break
         return junctions, connector_junction_ids
@@ -1038,7 +1078,9 @@ class GHEThermalLoop(object):
             tuple(ghe.duplicate() for ghe in self.ground_heat_exchangers),
             tuple(conn.duplicate() for conn in self.connectors), self.clockwise_flow,
             self.soil_parameters.duplicate(), self.fluid_parameters.duplicate(),
-            self.pipe_parameters.duplicate(), self.borehole_parameters.duplicate())
+            self.pipe_parameters.duplicate(), self.borehole_parameters.duplicate(),
+            self.design_parameters.duplicate(),
+            self.horizontal_pipe_parameters.duplicate())
         new_loop._display_name = self._display_name
         return new_loop
 
